@@ -1,6 +1,6 @@
 /* font-manager-fontconfig.c
  *
- * Copyright (C) 2009 - 2021 Jerry Casiano
+ * Copyright (C) 2009-2022 Jerry Casiano
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -65,38 +65,6 @@ is_legacy_format (FcPattern *pat)
             g_strcmp0((const gchar *) format, "TrueType") != 0);
 }
 
-/* From pangofc-fontmap.c */
-static GList *
-list_charset (const FcCharSet *charset)
-{
-    GList *result = NULL;
-    FcChar32  ucs4, pos;
-    FcChar32  map[FC_CHARSET_MAP_SIZE];
-
-    for (ucs4 = FcCharSetFirstPage (charset, map, &pos);
-         ucs4 != FC_CHARSET_DONE;
-         ucs4 = FcCharSetNextPage (charset, map, &pos)) {
-
-        for (int i = 0; i < FC_CHARSET_MAP_SIZE; i++) {
-            int b = 0;
-            FcChar32 bits = map[i];
-            FcChar32 base = ucs4 + i * 32;
-            while (bits) {
-                if (bits & 1) {
-                    gunichar ch = (base + b);
-                    if (unicode_unichar_isgraph(ch))
-                        result = g_list_prepend(result, GINT_TO_POINTER(ch));
-                }
-                bits >>= 1;
-                b++;
-            }
-        }
-
-    }
-
-    return g_list_reverse(result);
-}
-
 static void
 process_fontset (const FcFontSet *fontset, JsonObject *json_obj)
 {
@@ -203,6 +171,7 @@ font_manager_list_available_font_files (void)
 {
     FcPattern *pattern = FcPatternBuild(NULL,NULL);
     FcObjectSet *objectset = FcObjectSetBuild (FC_FILE, FC_FONTFORMAT, NULL);
+    g_assert(FcPatternAddBool(pattern, FC_VARIABLE, FcFalse));
     FcFontSet *fontset = FcFontList(FcConfigGetCurrent(), pattern, objectset);
     GList *result = NULL;
 
@@ -307,6 +276,7 @@ font_manager_list_available_font_families (void)
 {
     GList *result = NULL;
     FcPattern *pattern = FcPatternBuild(NULL,NULL);
+    g_assert(FcPatternAddBool(pattern, FC_VARIABLE, FcFalse));
     FcObjectSet *objectset = FcObjectSetBuild(FC_FAMILY, FC_FONTFORMAT, NULL);
     FcFontSet *fontset = FcFontList(FcConfigGetCurrent(), pattern, objectset);
 
@@ -364,9 +334,14 @@ font_manager_get_available_fonts (const gchar *family_name)
     FcPattern *pattern = NULL;
 
     if (family_name)
-        pattern = FcPatternBuild (NULL, FC_FAMILY, FcTypeString, family_name, NULL);
+        pattern = FcPatternBuild (NULL,
+                                  FC_FAMILY, FcTypeString, family_name,
+                                  FC_VARIABLE, FcTypeBool, FcFalse,
+                                  NULL);
     else
-        pattern = FcPatternBuild (NULL, NULL);
+        pattern = FcPatternBuild (NULL,
+                                  FC_VARIABLE, FcTypeBool, FcFalse,
+                                  NULL);
 
     FcObjectSet *objectset = FcObjectSetBuild(FC_FILE,
                                               FC_INDEX,
@@ -412,6 +387,7 @@ font_manager_get_available_fonts_for_lang (const gchar *lang_id)
 
     g_assert(FcLangSetAdd(langset, language));
     g_assert(FcPatternAddLangSet(pattern, FC_LANG, langset));
+    g_assert(FcPatternAddBool(pattern, FC_VARIABLE, FcFalse));
 
     FcObjectSet *objectset = FcObjectSetBuild(FC_FILE,
                                               FC_INDEX,
@@ -472,6 +448,8 @@ font_manager_get_available_fonts_for_chars (const gchar *chars)
     FcPattern *pattern = FcPatternCreate();
     FcCharSet *charset = FcCharSetCreate();
 
+    g_assert(FcPatternAddBool(pattern, FC_VARIABLE, FcFalse));
+
     for (int i = 0; i < n_chars; i++) {
         wc = g_utf8_get_char(p);
         g_assert(FcCharSetAddChar(charset, wc));
@@ -634,101 +612,6 @@ font_manager_get_attributes_from_filepath (const gchar *filepath, int index, GEr
     return json_obj;
 }
 
-/**
- * font_manager_get_charset_from_fontconfig_pattern: (skip)
- * @pattern: FcPattern to examine
- *
- * Supplied FcPattern must contain an FcCharSet.
- *
- * Returns: (element-type gunichar) (transfer container) (nullable):
- * a newly created #GSList of codepoints or %NULL.
- * The returned list should be freed using #g_slist_free when no longer needed.
- */
-GList *
-font_manager_get_charset_from_fontconfig_pattern (FcPattern *pattern)
-{
-    GList *result = NULL;
-    FcCharSet *charset = NULL;
-    if (FcPatternGetCharSet(pattern, FC_CHARSET, 0, &charset) == FcResultMatch)
-        result = list_charset(charset);
-    return result;
-}
-
-/**
- * font_manager_get_charset_from_font_object:
- * @font_object: #JsonObject
- *
- * Returns: (element-type gunichar) (transfer container) (nullable):
- * a newly created #GSList of codepoints or %NULL.
- * The returned list should be freed using #g_slist_free when no longer needed.
- */
-GList *
-font_manager_get_charset_from_font_object (JsonObject *font_object)
-{
-    int index = json_object_get_int_member(font_object, "findex");
-    const gchar *filepath = json_object_get_string_member(font_object, "filepath");
-    FcPattern *pattern = FcPatternBuild(NULL,
-                                         FC_FILE, FcTypeString, filepath,
-                                         FC_INDEX, FcTypeInteger, index,
-                                         NULL);
-    FcObjectSet *objectset = FcObjectSetBuild(FC_CHARSET, NULL);
-    FcFontSet *fontset = FcFontList(FcConfigGetCurrent(), pattern, objectset);
-    GList *result = NULL;
-    if (fontset->nfont > 0)
-        result = font_manager_get_charset_from_fontconfig_pattern(fontset->fonts[0]);
-    FcObjectSetDestroy(objectset);
-    FcPatternDestroy(pattern);
-    FcFontSetDestroy(fontset);
-    return result ? result : font_manager_get_charset_from_filepath(filepath, index);
-}
-
-/**
- * font_manager_get_charset_from_filepath:
- * @filepath: full path to font file to query
- * @index: index of face within file to select
- *
- * Returns: (element-type gunichar) (transfer container) (nullable):
- * a newly created #GSList of codepoints or %NULL.
- * The returned list should be freed using #g_slist_free when no longer needed.
- */
-GList *
-font_manager_get_charset_from_filepath (const gchar *filepath, int index)
-{
-    FT_Face         face;
-    FT_Library      library;
-    FT_Error         error;
-
-    gsize           filesize = 0;
-    g_autofree gchar *font = NULL;
-
-    GList *result = NULL;
-
-    if (G_UNLIKELY(!g_file_get_contents(filepath, &font, &filesize, NULL))) {
-        return result;
-    }
-
-    error = FT_Init_FreeType(&library);
-    if (G_UNLIKELY(error)) {
-        return result;
-    }
-
-    error = FT_New_Memory_Face(library, (const FT_Byte *) font, (FT_Long) filesize, index, &face);
-    if (G_UNLIKELY(error)) {
-        return result;
-    }
-
-    FcBlanks *blanks = FcBlanksCreate();
-    FcCharSet *charset = FcFreeTypeCharSet(face, blanks);
-    result = list_charset(charset);
-    if (!result && ((int) FcCharSetCount(charset) > 0))
-        g_warning(G_STRLOC " : Failed to create FcCharSet for %s", filepath);
-    FT_Done_Face(face);
-    FT_Done_FreeType(library);
-    FcBlanksDestroy(blanks);
-    FcCharSetDestroy(charset);
-    return result;
-}
-
 /**
  * font_manager_sort_json_font_listing:
  * @json_obj: #JsonObject returned from #font_manager_get_available_fonts*
@@ -880,7 +763,7 @@ font_manager_weight_defined (FontManagerWeight weight)
 GType
 font_manager_weight_get_type (void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__volatile = 0;
 
   if (g_once_init_enter (&g_define_type_id__volatile))
     {
@@ -929,7 +812,7 @@ font_manager_slant_to_string (FontManagerSlant slant)
 GType
 font_manager_slant_get_type (void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__volatile = 0;
 
   if (g_once_init_enter (&g_define_type_id__volatile))
     {
@@ -1006,7 +889,7 @@ font_manager_width_defined (FontManagerWidth width)
 GType
 font_manager_width_get_type (void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__volatile = 0;
 
   if (g_once_init_enter (&g_define_type_id__volatile))
     {
@@ -1056,7 +939,7 @@ font_manager_spacing_to_string (FontManagerSpacing spacing)
 GType
 font_manager_spacing_get_type (void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__volatile = 0;
 
   if (g_once_init_enter (&g_define_type_id__volatile))
     {
@@ -1103,7 +986,7 @@ font_manager_subpixel_order_to_string (FontManagerSubpixelOrder rgba)
 GType
 font_manager_subpixel_order_get_type (void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__volatile = 0;
 
   if (g_once_init_enter (&g_define_type_id__volatile))
     {
@@ -1148,7 +1031,7 @@ font_manager_hint_style_to_string (FontManagerHintStyle hinting)
 GType
 font_manager_hint_style_get_type (void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__volatile = 0;
 
   if (g_once_init_enter (&g_define_type_id__volatile))
     {
@@ -1191,7 +1074,7 @@ font_manager_lcd_filter_to_string (FontManagerLCDFilter filter)
 GType
 font_manager_lcd_filter_get_type (void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__volatile = 0;
 
   if (g_once_init_enter (&g_define_type_id__volatile))
     {
