@@ -1,6 +1,6 @@
 /* font-manager-orthography.h
  *
- * Copyright (C) 2009 - 2021 Jerry Casiano
+ * Copyright (C) 2009-2022 Jerry Casiano
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,10 +21,9 @@
 #ifndef __FONT_MANAGER_ORTHOGRAPHY_H__
 #define __FONT_MANAGER_ORTHOGRAPHY_H__
 
+#include <hb.h>
 #include <glib.h>
 #include <json-glib/json-glib.h>
-#include <fontconfig/fontconfig.h>
-#include <fontconfig/fcfreetype.h>
 #include <pango/pango-language.h>
 
 #include "font-manager-json-proxy.h"
@@ -33,7 +32,7 @@
 G_BEGIN_DECLS
 
 JsonObject * font_manager_get_orthography_results (JsonObject *font);
-gchar * font_manager_get_sample_string_for_orthography (JsonObject *orthography, GList *charset);
+gchar * font_manager_get_sample_string (JsonObject *font);
 
 static const FontManagerJsonProxyProperties OrthographyProperties [] =
 {
@@ -173,6 +172,7 @@ static const FontManagerOrthographyData UncategorizedOrthographies [] = {
 #include "MathematicalOperators"
 #include "ChessSymbols"
 #include "Emoticons"
+#include "RegionalFlags"
 
 //
 // Indic:
