@@ -1,6 +1,6 @@
 /* font-manager-preview-pane.h
  *
- * Copyright (C) 2009 - 2021 Jerry Casiano
+ * Copyright (C) 2009-2022 Jerry Casiano
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,7 +57,7 @@ GtkWidget * font_manager_preview_pane_new (void);
 void font_manager_preview_pane_show_uri (FontManagerPreviewPane *self, const gchar *uri, int index);
 void font_manager_preview_pane_set_font (FontManagerPreviewPane *self, FontManagerFont *font);
 void font_manager_preview_pane_set_orthography (FontManagerPreviewPane *self, FontManagerOrthography *orthography);
-void font_manager_preview_pane_set_max_waterfall_size (FontManagerPreviewPane *self, gdouble size_points);
+void font_manager_preview_pane_set_waterfall_size (FontManagerPreviewPane *self, gdouble min_size, gdouble max_size, gdouble ratio);
 void font_manager_preview_pane_restore_state (FontManagerPreviewPane *self, GSettings *settings);
 
 G_END_DECLS
